aboutsummaryrefslogtreecommitdiff
path: root/lib/url.c
diff options
context:
space:
mode:
authorDaniel Stenberg <daniel@haxx.se>2000-10-06 11:03:20 +0000
committerDaniel Stenberg <daniel@haxx.se>2000-10-06 11:03:20 +0000
commitc58dc8f82fc65e7279ad2e6ad306202fc17c9af8 (patch)
treede1ca6689cedec6650b6a7958556a2ae570b62db /lib/url.c
parent0ddacf929af9418d588b431211d579478759aaf3 (diff)
the --interface code doesn't work on win32 and is #ifndef WIN32 now
Diffstat (limited to 'lib/url.c')
-rw-r--r--lib/url.c13
1 files changed, 9 insertions, 4 deletions
diff --git a/lib/url.c b/lib/url.c
index 3865d201e..640b8597a 100644
--- a/lib/url.c
+++ b/lib/url.c
@@ -109,7 +109,6 @@
#include "progress.h"
#include "cookie.h"
#include "strequal.h"
-#include "writeout.h"
/* And now for the protocols */
#include "ftp.h"
@@ -1206,9 +1205,14 @@ CURLcode curl_connect(CURL *curl, CURLconnect **in_connect)
conn->serv_addr.sin_family = conn->hp->h_addrtype;
conn->serv_addr.sin_port = htons(data->port);
-/* sck 8/31/2000 add support for specifing device to bind socket to */
-/* #ifdef LINUX */
-/* I am using this, but it may not work everywhere, only tested on RedHat 6.2 */
+#ifndef WIN32
+ /* We don't generally like checking for OS-versions, we should make this
+ HAVE_XXXX based, although at the moment I don't have a decent test for
+ this! */
+
+ /* sck 8/31/2000 add support for specifing device to bind socket to */
+ /* I am using this, but it may not work everywhere, only tested on
+ RedHat 6.2 */
#ifdef HAVE_INET_NTOA
#ifndef INADDR_NONE
@@ -1337,6 +1341,7 @@ CURLcode curl_connect(CURL *curl, CURLconnect **in_connect)
} /* end of device selection support */
#endif /* end of HAVE_INET_NTOA */
+#endif /* end of not WIN32 */
if (connect(data->firstsocket,
(struct sockaddr *) &(conn->serv_addr),